@@ -92,7 +92,7 @@ class CommunityJobOffer(Model):
 
 @receiver(pre_save, sender=Community)
 def pre_create_account(sender, instance, **kwargs):
-    if getattr(instance, "urlid", "").startswith(settings.SITE_URL) and getattr(instance, "urlid", "") != "":
+    if not instance.urlid or instance.urlid.startswith(settings.SITE_URL):
         if getattr(instance, Model.slug_field(instance)) != slugify(instance.name):
             if Community.objects.filter(slug=slugify(instance.name)).count() > 0:
                 raise Exception(_("Name already taken"))
